@@ -128,7 +128,7 @@ void TimeLabels::updateConfig()
     if (use12Clock()) {
         test = QStringLiteral("12");
     }
-    mMiniWidth = fontMetrics().width(test);
+    mMiniWidth = fontMetrics().boundingRect(test).width();
     if (use12Clock()) {
         test = QStringLiteral("pm");
     } else {
@@ -137,7 +137,7 @@ void TimeLabels::updateConfig()
     QFont sFont = font();
     sFont.setPointSize(sFont.pointSize() / 2);
     QFontMetrics fmS(sFont);
-    mMiniWidth += fmS.width(test) + frameWidth() * 2 + 4;
+    mMiniWidth += fmS.boundingRect(test).width() + frameWidth() * 2 + 4;
 
     /** Can happen if all resources are disabled */
     if (!mAgenda) {
@@ -173,12 +173,18 @@ void TimeLabels::setAgenda(Agenda *agenda)
 
 int TimeLabels::yposToCell(const int ypos) const
 {
-   const auto firstDay =
-       QDateTime(mAgenda->dateList().first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
-    const int beginning = // the hour we start drawing with
-        !mTimezone.isValid() ?
-        0 :
-        (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
+    const KCalCore::DateList datelist = mAgenda->dateList();
+    if (datelist.isEmpty()) {
+        return 0;
+    }
+
+    const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
+    const int beginning   // the hour we start drawing with
+        = !mTimezone.isValid()
+          ? 0
+          : (mTimezone.offsetFromUtc(firstDay)
+             -mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
+
     return static_cast<int>(ypos / mCellHeight) + beginning;
 }
 
@@ -230,19 +236,24 @@ void TimeLabels::paintEvent(QPaintEvent *)
     if (!mAgenda) {
         return;
     }
+    const KCalCore::DateList datelist = mAgenda->dateList();
+    if (datelist.isEmpty()) {
+        return;
+    }
+
     QPainter p(this);
 
     const int ch = height();
 
     // We won't paint parts that aren't visible
-    const int cy = -y();// y() returns a negative value.
+    const int cy = -y(); // y() returns a negative value.
 
-    const auto firstDay =
-        QDateTime(mAgenda->dateList().first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
-    const int beginning =
-        !mTimezone.isValid() ?
-        0 :
-        (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
+    const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
+    const int beginning
+        = !mTimezone.isValid()
+          ? 0
+          : (mTimezone.offsetFromUtc(firstDay)
+             -mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
 
     // bug:  the parameters cx and cw are the areas that need to be
     //       redrawn, not the area of the widget.  unfortunately, this
@@ -290,7 +301,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
     suffixFont.setPointSize(suffixFont.pointSize() / 2);
     QFontMetrics fmS(suffixFont);
     const int startW = cw - frameWidth() - 2;
-    const int tw2 = fmS.width(suffix);
+    const int tw2 = fmS.boundingRect(suffix).width();
     const int divTimeHeight = (timeHeight - 1) / 2 - 1;
     //testline
     //p->drawLine(0,0,0,contentsHeight());
@@ -313,7 +324,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
 
         // draw the time label
         p.setPen(textColor);
-        const int timeWidth = fm.width(hour);
+        const int timeWidth = fm.boundingRect(hour).width();
         int offset = startW - timeWidth - tw2 - 1;
         p.setFont(hourFont);
         p.drawText(offset, static_cast<int>(y + timeHeight), hour);
@@ -341,9 +352,9 @@ void TimeLabels::contextMenuEvent(QContextMenuEvent *event)
                                              i18n("&Add Timezones..."));
     QAction *removeTimeZone = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
                                               i18n("&Remove Timezone %1", i18n(mTimezone.id().constData())));
-    if (!mTimezone.isValid() ||
-        !mTimeLabelsZone->preferences()->timeScaleTimezones().count() ||
-        mTimezone == mTimeLabelsZone->preferences()->timeZone()) {
+    if (!mTimezone.isValid()
+        || !mTimeLabelsZone->preferences()->timeScaleTimezones().count()
+        || mTimezone == mTimeLabelsZone->preferences()->timeZone()) {
         removeTimeZone->setEnabled(false);
     }
 
@@ -427,7 +438,7 @@ bool TimeLabels::event(QEvent *event)
         toolTip += QLatin1String("<qt>");
         toolTip += i18nc("[hour of the day][am/pm/00] [timezone id (timezone-offset)]",
                          "%1%2<br/>%3 (%4)",
-                         cellToHour(cell),  cellToSuffix(cell),
+                         cellToHour(cell), cellToSuffix(cell),
                          i18n(mTimezone.id().constData()),
                          KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
         toolTip += QLatin1String("</qt>");
